# Machine Learning

try:
    from . import __sklearn__ as sklearn
except:
    pass

try:
    import xgboost as xgb; import xgboost
except:
    pass

# And plotting
# from fxy.p import *
